-- Drop functions that we no longer use
DROP FUNCTION IF EXISTS insert_to_table_function(DATE, TIME, VARCHAR, TIMESTAMP, INTEGER, TIMESTAMP, VARCHAR, VARCHAR, VARCHAR, INTEGER, TEXT, TEXT);
DROP FUNCTION IF EXISTS load_to_table_function(DATE, TIME, VARCHAR);
DROP FUNCTION IF EXISTS drop_table_function(VARCHAR);
DROP FUNCTION IF EXISTS get_location_mask(VARCHAR);
DROP FUNCTION IF EXISTS get_location(BIT);
DROP FUNCTION IF EXISTS register_table(VARCHAR, BIT);
DROP FUNCTION IF EXISTS unregister_table(VARCHAR, BIT);
DROP FUNCTION IF EXISTS change_import_status(VARCHAR, VARCHAR);
DROP FUNCTION IF EXISTS insert_usergroup(VARCHAR, VARCHAR);
DROP FUNCTION IF EXISTS delete_usergroup(VARCHAR, VARCHAR);
DROP FUNCTION IF EXISTS insert_filteruser(VARCHAR, VARCHAR, BIT);
DROP FUNCTION IF EXISTS delete_filteruser(VARCHAR, VARCHAR);
DROP FUNCTION IF EXISTS insert_filtergroup(VARCHAR, VARCHAR, BIT);
DROP FUNCTION IF EXISTS delete_filtergroup(VARCHAR, VARCHAR);
DROP FUNCTION IF EXISTS show_global_filters(VARCHAR);
DROP FUNCTION IF EXISTS show_own_filters(VARCHAR);
DROP FUNCTION IF EXISTS show_user_groups(VARCHAR);
DROP FUNCTION IF EXISTS show_group_users(VARCHAR);
DROP FUNCTION IF EXISTS insert_own_filter(VARCHAR, VARCHAR, VARCHAR, VARCHAR);
DROP FUNCTION IF EXISTS insert_global_filter(VARCHAR, VARCHAR);
DROP FUNCTION IF EXISTS update_own_filter(VARCHAR, VARCHAR);
DROP FUNCTION IF EXISTS show_filter_users(VARCHAR);
DROP FUNCTION IF EXISTS show_filter_groups(VARCHAR);
DROP FUNCTION IF EXISTS show_non_filter_groups(VARCHAR);
DROP FUNCTION IF EXISTS show_available_users(VARCHAR);
DROP FUNCTION IF EXISTS make_filter_own(VARCHAR, VARCHAR);
DROP FUNCTION IF EXISTS get_parent(VARCHAR);
DROP FUNCTION IF EXISTS show_group_filters(VARCHAR);
DROP FUNCTION IF EXISTS create_new_tables_function(DATE);

-- Recrate messages table since we need to redo the layout and purge db
DROP TABLE IF EXISTS messages CASCADE;
CREATE TABLE messages 
 (
    id BIGINT NOT NULL DEFAULT nextval('messages_id_seq'), 
    ip VARCHAR(110) NOT NULL DEFAULT '0',
    rtime TIMESTAMP NOT NULL,
    facsev INTEGER NOT NULL, 
    mtime TIMESTAMP,
    host VARCHAR(129) DEFAULT NULL, 
    ident VARCHAR(80) DEFAULT NULL, 
    pid VARCHAR(128), 
    event INT,
    msg TEXT NOT NULL, 
    fts TEXT DEFAULT '',
    PRIMARY KEY (id, rtime)
 );
CREATE INDEX messages_fts_idx ON messages USING gin( to_tsvector('english', fts) );

CREATE OR REPLACE FUNCTION create_table_function( tbl_date DATE )
RETURNS BOOLEAN AS $$
DECLARE
    table_name CHAR(25);
BEGIN
    table_name := 'messages_' || REPLACE(tbl_date::text, '-', '_');
    IF EXISTS (
        SELECT *
        FROM   pg_catalog.pg_tables 
        WHERE    tablename  = table_name
        ) THEN
        RETURN FALSE;
    ELSE
        EXECUTE ( 'CREATE TABLE ' || table_name || ' (
            PRIMARY KEY (id, rtime)
            ) INHERITS (messages);' );
    END IF;
    RETURN TRUE;
END;
$$
LANGUAGE plpgsql;

--UPDATE db VERSION
UPDATE service SET version = 14;
