-- Drop functions that we no longer use
-- Recrate messages table since we need to redo the layout and purge db
DROP TABLE IF EXISTS messages CASCADE;
CREATE TABLE messages 
 (
    id BIGINT NOT NULL DEFAULT nextval('messages_id_seq'), 
    ip VARCHAR(110) NOT NULL DEFAULT '0',
    rtime TIMESTAMP NOT NULL,
    facsev INTEGER NOT NULL, 
    mtime TIMESTAMP,
    host VARCHAR(129) DEFAULT NULL, 
    ident VARCHAR(80) DEFAULT NULL, 
    pid VARCHAR(128), 
    event INT,
    msg TEXT NOT NULL, 
    fts TEXT DEFAULT '',
    PRIMARY KEY (id, rtime)
 );
CREATE INDEX messages_fts_idx ON messages USING gin( to_tsvector('english', fts) );

CREATE OR REPLACE FUNCTION create_table_function( tbl_date TIMESTAMP )
RETURNS BOOLEAN AS $$
DECLARE
    table_name CHAR(30);
    the_hour CHAR(2);
BEGIN
    the_hour := (select extract(hour from tbl_date::timestamp))::text;
    IF (the_hour::int < 10) THEN
        the_hour := '0'||the_hour::text;
    END IF;

    table_name := 'messages_' || REPLACE((tbl_date::DATE)::text, '-','_') || '_' || the_hour::text;
    IF EXISTS (
        SELECT *
        FROM   pg_catalog.pg_tables 
        WHERE    tablename  = table_name
        ) THEN
        RETURN FALSE;
    ELSE
        EXECUTE ( 'CREATE TABLE ' || table_name || ' (
            PRIMARY KEY (id, rtime)
            ) INHERITS (messages);' );
    END IF;
--    IF ( SELECT create_fts_index FROM settings ) THEN
--                EXECUTE ( 'CREATE INDEX ' || table_name || '_key ON ' || table_name || ' USING gin( to_tsvector(''english'', fts) )');
--    END IF;
    RETURN TRUE;
END;
$$
LANGUAGE plpgsql;

--UPDATE db VERSION
UPDATE service SET version = 15;
